import 'package:equatable/equatable.dart';
import 'package:flutter/cupertino.dart';
import 'package:zhiying_base_widget/widgets/custom/multi_nav/model/custom_quick_entry_model.dart';


abstract class CustomQuickEntryState extends Equatable {
  const CustomQuickEntryState();

  @override
  List<Object> get props => [];
}

/// 初始化状态
class InitialCustomQuickEntryState extends CustomQuickEntryState {
  @override
  List<Object> get props => [];
}

/// 加载数据完毕
class CustomQuickEntryLoadedState extends CustomQuickEntryState {
  final CustomQuickEntryModel model;

  const CustomQuickEntryLoadedState({@required this.model});

  @override
  List<Object> get props => [this.model];
}

/// 加载缓存数据
class CustomQuickEntryCachedState extends CustomQuickEntryState {
  final CustomQuickEntryModel model;

  const CustomQuickEntryCachedState({@required this.model});

  @override
  List<Object> get props => [this.model];
}

/// 加载数据出错
class CustomQuickEntryErrorState extends CustomQuickEntryState {}
